-- Library's Purpose:  Path String Manipulation

-- Copyright 1998 : Mathew Hounsell
-- Version : 1.0
-- Licence : FreeCode

-- For assistance of Euphoria Programmers.

-- For DOS/WINDOWS style file naming system. Supports long file names.

---------------------------------------------------------------------------
-- NAME    : split_path_file()
-- PURPOSE : Determines a files name and from it's full path.
-- ARGS    : sequence s - the files full path.
-- RETURNS : sequence - in the form { path, filename }
-- NOTES   : If it find no '\' path is empty.
--           If there is a path it will be returned ending in a '\'.
--           If there is a drive letter at start of s it will be returned
--              as is at the start of the path.
-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
global function split_path_file(sequence s)
sequence val

    val = {}
    for t = length(s) to 1 by -1 do
        if s[t] = '\\' then
            val = {s[1..t],s[t+1..length(s)]}
            exit
        end if
    end for
    if not length(val) then
        val = { {}, s }
    end if
    return val
end function

---------------------------------------------------------------------------
-- NAME    : split_name_ext()
-- PURPOSE : Gets a files name and it's extension from it's full file name.
-- ARGS    : sequence s - the full full name.
-- RETURNS : sequence - of the form { name, extension }
-- NOTE    : If it doesn't find a '.' the extension is empty.
--           If there is an extension it will be returned preceded by a '.'.
-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
global function split_name_ext(sequence s)
sequence val

    val = {}
    for t = length(s) to 1 by -1 do
        if s[t] = '.' then
            val = {s[1..t-1],s[t..length(s)]}
            exit
        end if
    end for
    if not length(val) then
        val = { s , {} }
    end if
    return val
end function

---------------------------------------------------------------------------
-- NAME    : split_drive_path()
-- PURPOSE : Gets a files drive from it's full path.
-- ARGS    : sequence s - The files full path.
-- RETURNS : sequence - Of the form { drive, path }
-- NOTES   : If there is no ':' the drive will be returned as empty.
--           If there is a drive it will be returned ending in a ':'.
-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
global function split_drive_path(sequence s)
sequence val

    val = {}
    for t = 1 to length(s) by 1 do
        if s[t] = ':' then
            val = {s[1..t],s[t+1..length(s)]}
            exit
        end if
    end for
    if not length(val) then
        val = { {}, s }
    end if
    return val
end function

---------------------------------------------------------------------------
-- NAME    : split_drive_path_name_ext()
-- PURPOSE : Determines a files drive, path, name and extenssion from
--              it's full path.
-- ARGS    : sequence s - The files full path.
-- RETURNS : sequence - Of the form { drive, path, name, extension }
-- NOTES   : If it was unable to find a part it will be empty.
--           If there is a path it will be returned ending in a '\'.
--           If there is a drive it will be returned ending in a ':'.
--           If there is an extension it will be returned preceded by a '.'.
-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
global function split_drive_path_name_ext(sequence s)
object val

    val = {}
    s = split_path_file(s)
    if length(s) = 2 then
        val = split_drive_path(s[1]) & split_name_ext(s[2])
    else
        val = { {}, {}, {}, s }
    end if
    return val
end function

---------------------------------------------------------------------------
-- End Of Code and File
---------------------------------------------------------------------------

